import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Two numbers that are the same or add up to ten can be matched when clicked.
 * 
 * Author: Sarah Coakley
 * Date: May 23, 2019
 */
public class Number extends Actor
{
    //Variables and Arrays used
    private int number;
    private static GreenfootImage[] imgs = new GreenfootImage[19];
    
    static
    {
        Color orange = new Color(255,161,38);
        Color red = new Color(163,8,3);
        Color green = new Color(8,204,11);
        Color blue = new Color(37,113,234);
       
        //Creates an image that is 45x45
        GreenfootImage tile = new GreenfootImage(45, 45);
        GreenfootImage actTile = new GreenfootImage(tile);
        
        //Sets the font of the image
        Font font = new Font("Courier", true, false, 45);
        tile.setFont(font);
        
        //Frames the tile with a gray square
        tile.setColor(Color.GRAY);
        tile.drawRect(0,0,45,45);
        
        //Makes a gray square
        actTile.setColor(Color.GRAY);
        actTile.fill();
        
        //Frames the activated tile with a gray square
        actTile.setColor(Color.GRAY);
        actTile.drawRect(0,0,45,45);
        
        //Sets the color and font of the activated tile
        actTile.setColor(Color.GRAY);
        actTile.setFont(font);
        
        //Sets the image of every number image, whether it is highlighted, activated, or not.
        for(int i = 0; i < imgs.length - 1; i++)
        {
            imgs[i] = new GreenfootImage(i/9 == 0 ? tile : actTile);
            
            //If 0, 8, 9, and 17 are encountered, make the number black
            if(i == 0 || i == 8 || i == 9 || i == 17)
            {
                imgs[i].setColor(Color.BLACK);
            }
            
            //If 1, 7, 10, and 16 are encountered, make the number orange
            else if(i == 1 || i == 7 || i == 10 || i == 16)
            {
                imgs[i].setColor(orange);
            }
            
            //If 2, 6, 11, and 15 are encountered, make the number red
            else if(i == 2 || i == 6 || i == 11 || i == 15)
            {
                imgs[i].setColor(red);
            }
            
            //If 3, 5, 12, and 14 are encountered, make the number green
            else if(i == 3 || i == 5 || i == 12 || i == 14)
            {
                imgs[i].setColor(green);
            }
            
            //If 4 and 13 are encountered, make the number blue
            else if(i == 4 || i == 13)
            {
                imgs[i].setColor(blue);
            }
            
            //Displays the number in the tile
            imgs[i].drawString("" + (i%9 + 1), 11, 38);
        }
    }
    
    public Number(int number)
    {
        //Makes sure the tile isn't already highlighted
        this.number = number;
        updateImage(false);
    }
    
    public void act() 
    {
        //If a number is clicked, change the transparency of the image
        if(Greenfoot.mouseClicked(this) && number != 0)
        {
            ((NumberWorld) getWorld()).pressedNumber(this);
            Greenfoot.playSound("click.wav");
        }
        
        //If a number is at the bottom of the world, remove it and stop the program
        if(atBottom())
        {
            getWorld().removeObject(this);
            Greenfoot.stop();
        }
    }
    
    public void changeHeight(int hy)
    {
        setLocation(getX(), getY() + hy);
    }
    
    public void changeWidth(int hx)
    {
        setLocation(getX() + hx, getY());
    }
    
    public void updateImage(boolean active)
    {
        //Makes a number active
        setImage(imgs[(number - 1) + (active ? 9 : 0)]);
    }
    
    public void setSolved()
    {
        //Sets the number to 0 and changes the image to the cover
        number = 0;
        setImage("cover.png");
    }
    
    public int getValue() 
    {
        return number;
    }
    
    public boolean getSolved() 
    {
        return number == 0;
    }
    
    private boolean atBottom()
    {
        //Returns the y coordinate of the number when a number is at the bottom of the world
        return getY() >= getWorld().getHeight() - 2;
    }
}
